@@ -192,7 +192,7 @@ def scatter_plot(
 
                    {crite} 
 
-                   GROUP BY boite, lat, lon, varno;"""
+                   GROUP BY boite, lat, lon, varno having sum(n)>3;"""
        cursor.execute(query)
 
        if len(filesin)>1:
@@ -210,7 +210,7 @@ def scatter_plot(
 
                        {crite} 
                      
-                       GROUP BY boite, lat, lon, varno;"""  
+                       GROUP BY boite, lat, lon, varno having sum(n)>3;"""  
 
            cursor.execute(query)
 
@@ -221,20 +221,20 @@ def scatter_plot(
                               BOITES1.vcoord VCOORD,
                               BOITES1.varno VARNO,
                               ABS(BOITES1.avg) - ABS(BOITES2.avg) AVG, --BOITES1.avg - BOITES2.avg AVG,
-                              ABS(BOITES1.avg) AVG1,
-                              ABS(BOITES2.avg) AVG2,
+                              COALESCE(ABS(BOITES1.avg),8888) AVG1,
+                              COALESCE(ABS(BOITES2.avg),8888) AVG2,
                               ABS(BOITES1.std) - ABS(BOITES2.std) STD, --  BOITES1.std - BOITES2.std STD, 
-                              ABS(BOITES1.std) std1,
-                              ABS(BOITES2.std) std2,
+                              COALESCE(ABS(BOITES1.std),8888) as  std1,
+                              COALESCE(ABS(BOITES2.std),8888) as std2,
                               ABS(BOITES1.bcorr) - ABS(BOITES2.bcorr) BCORR ,  --BOITES1.bcorr - BOITES2.bcorr BCORR , 
-                              ABS(BOITES1.bcorr) bcorr1,
-                              ABS(BOITES2.bcorr) bcorr2,
+                              COALESCE(ABS(BOITES1.bcorr),8888) AS bcorr1,
+                              COALESCE(ABS(BOITES2.bcorr),8888) AS bcorr2,
                               BOITES1.N - BOITES2.N  N , --BOITES1.N - BOITES2.N  N, 
-                              BOITES1.N N1 ,
-                              BOITES2.N N2 
+                              COALESCE(BOITES1.N, 8888) AS N1,
+                              COALESCE(BOITES2.N, 8888) AS N2
                       FROM BOITES1,BOITES2 
-                      WHERE  BOITES1.boite=BOITES2.boite and BOITES1.VCOORD=BOITES2.VCOORD""" 
-                      
+                      WHERE  BOITES1.boite=BOITES2.boite and BOITES1.VCOORD=BOITES2.VCOORD; 
+                      """ 
 
            cursor.execute(query)
        
@@ -270,7 +270,25 @@ def scatter_plot(
           bcorr = np.array([row[11] for row in results])
           bcorr1 = np.array([row[12] for row in results])
           bcorr2 =  np.array([row[13] for row in results])
-
+          con = sqlite3.connect('tu_base_de_datos.db')
+          
+        
+          sql = """
+        SELECT b1.boite, b1.lat, b1.lon
+        FROM boites1 b1
+        LEFT JOIN boites2 b2 ON b1.boite = b2.boite
+        WHERE b2.boite IS NULL
+        
+        UNION
+        
+        SELECT b2.boite, b2.lat, b2.lon
+        FROM boites2 b2
+        LEFT JOIN boites1 b1 ON b2.boite = b1.boite
+        WHERE b1.boite IS NULL
+        """
+          cursor.execute(sql)
+          resultados = cursor.fetchall()
+        
        dens = nombre/NPSURFLL(lat-deltay,lat+deltay,lon-deltax,lon + deltax)
 
 
@@ -302,7 +320,6 @@ def scatter_plot(
        Mu     = np.array([row[4] for row in results])
        Sigma  = np.array([row[5] for row in results])
        Nobs   = np.array([row[6] for row in results])
-       # Close the connection
 
        conn.close()
        typer=''
@@ -336,19 +353,18 @@ def scatter_plot(
            plt.rcParams['axes.linewidth'] = 1
            fontsize = 17
        
-           # Preliminares para límites y paleta según variable
            OMPm = [value for value in OMP if isinstance(value, float)]
            vmin = np.nanmin(OMPm)
            vmax = np.nanmax(OMPm)
            Ninterv = 10
        
-           # Ajustes por tipo de variable
            if vartyp == 'dens' or vartyp == 'dens%' :
                OMP = dens / NDAYS 
                if len(filesin) > 1:
                   den1 = N1/NPSURFLL(lat-deltay,lat+deltay,lon-deltax,lon + deltax) 
                   den2 = N2/NPSURFLL(lat-deltay,lat+deltay,lon-deltax,lon + deltax) 
-                  OMP = (den2-den1)*100/den1
+                  OMP = (den2-den1)*100/den1  
+
                   vmin = -100
                   vmax =  100
                else:
@@ -367,6 +383,7 @@ def scatter_plot(
                    N1=N1 / NDAYS
 #
                    N2=N2/ NDAYS
+
                    OMP =(N2-N1)*100/N1
                    vmin = -100
                    vma = 100
@@ -384,7 +401,7 @@ def scatter_plot(
                    vmin, vmax = -max_abs, max_abs
            elif vartyp == 'obs':
                if len(filesin) > 1:
-                   OMP =(abs(avg2)-abs(avg1))*100/-abs(avg1)
+                   OMP =(abs(avg2)-abs(avg1))*100/abs(avg1)
                    vmin = -100
                    vmax= 100
 
@@ -394,7 +411,7 @@ def scatter_plot(
                   cmap_base = cm.get_cmap('RdYlBu_r', lut=Ninterv)  
            elif vartyp == 'bcorr':
                if len(filesin) > 1:
-                   OMP =(abs(bcorr2)-abs(bcorr1))*100/-abs(bcorr1)
+                   OMP =(abs(bcorr2)-abs(bcorr1))*100/abs(bcorr1)
                    vmin = -100
                    vmax= 100
 
@@ -406,8 +423,10 @@ def scatter_plot(
            elif vartyp in ['omp', 'oma', 'bcorr', 'stdomp']:
                vmin = np.min(OMP)
                vmax = np.max(OMP)
+
                if len(filesin) > 1:
-                   OMP =(abs(avg2)-abs(avg1))*100/-abs(avg1)
+                   
+                   OMP =(abs(avg2)-abs(avg1))*100/abs(avg1)
                    vmin = -100
                    vmax = 100
 
@@ -424,33 +443,24 @@ def scatter_plot(
            else:
                cmap_base = cm.get_cmap('RdYlBu_r', lut=Ninterv)
        
-           # Sincronización: límites, colormap y norm para poligonos y colorbar
            if len(filesin) > 1:
-              N = 21  # Debe ser impar!
-             # vmax = max(np.abs(OMP))
-             # vmin = -vmax
+              N = 21  
               boundaries = np.linspace(vmin, vmax, N)
               y = (boundaries[:-1] + boundaries[1:]) / 2
               neg_colors = [cm.RdYlBu_r(x) for x in np.linspace(0.08, 0.40, N//2)]
               blanco = (1, 1, 1, 1) 
               blanco = (1.0, 1.0, 0.6, 1.0) 
               pos_colors = [cm.RdYlBu_r(x) for x in np.linspace(0.60, 0.92, N//2)]
-       #       colores = neg_colors + [blanco] + pos_colors 
-              over_color = '#e600c7'   # fucsia, igual que set_over
-              under_color = '#0235ad'  # azul, igual que set_under
+              over_color = '#e600c7'   
+              under_color = '#0235ad' 
               colores =  neg_colors + [blanco] + pos_colors  
 
-            #a  colores = neg_colors + pos_colors
               cmap = colors.ListedColormap(colores)
               cmap.set_under('#0235ad')
               cmap.set_over('#e600c7')
-              #cmap.set_under(colores[0])     # mismo que el extremo negativo
-              #cmap.set_over(colores[-1])  
               norm = colors.BoundaryNorm(boundaries, N)
               extend_color = 'both'
               ticks = boundaries
-            #  if 0 not in ticks:
-            #      ticks = sorted(np.append(ticks, 0))
            else:
                boundaries = np.linspace(vmin, vmax, Ninterv + 1)
                y = boundaries[:-1] + (boundaries[1] - boundaries[0]) / 2
@@ -458,13 +468,11 @@ def scatter_plot(
                norm = cm.colors.Normalize(vmin=vmin, vmax=vmax)
                extend_color = None
                ticks = boundaries
-###########
            m = cm.ScalarMappable(norm=norm, cmap=cmap)
            Colors = [m.to_rgba(x) for x in y]
            inds = np.digitize(OMP, boundaries) - 1
            inds = np.clip(inds, 0, len(Colors) - 1)
        
-           # Proyección y ploteo de datos
            nombres = 0
            left, bottom = 0.90, 0.15
            ax, fig, LATPOS, PROJ, pc = pikobs.type_projection(proj)
@@ -486,25 +494,33 @@ def scatter_plot(
                        plt.text(point[0], point[1], int(np.floor(nombre[i])), color="k", fontsize=17, zorder=5, ha='center', va='center', weight='bold')
                    else: 
                        if boxsizex >=10:
-                          plt.text(point[0], point[1], round_first_digit_3(OMP[i]), color="k", fontsize=5, zorder=5, ha='center', va='center', weight='bold')
+                          plt.text(point[0], point[1], round_first_digit_3(OMP[i]), color="b", fontsize=5, zorder=5, ha='center', va='center', weight='bold')
                      
                        points4 = projectPpoly(PROJ, lat[i], lon[i], deltax, deltay, pc)
                        
                        valor = OMP[i]
 
                        if valor < vmin:
-                           col = '#0235ad'         # mismo que cmap.set_under
+                           col = '#0235ad'        
                        elif valor > vmax:
-                           col = '#e600c7'         # mismo que cmap.set_over
+                           col = '#e600c7'         
                        else:
                            ind = np.digitize(valor, boundaries) - 1
-                           # Asegúrate de que ind esté dentro de rango (casi siempre lo estará aquí)
-                           col = Colors[inds[i]]       # tu array de N-1 colores (NO incluye over/under)
+                           col = Colors[inds[i]]     
                        if len(filesin) == 1:
 
                            col = Colors[inds[i]]
+
+                       
                        poly = plt.Polygon(points4, fc=col, zorder=4, ec='k', lw=0.2, alpha=1.0)
                        ax.add_patch(poly)
+           for boite, latn, lonn in resultados:
+             points4 = projectPpoly(PROJ, latn, lonn, deltax, deltay, pc)
+
+             poly = plt.Polygon(points4, fc=(0,0,0,1), zorder=4, ec='k', lw=0.8, alpha=1.0)
+             ax.add_patch(poly)
+
+
        
            ax.coastlines()
            ax.add_feature(cartopy.feature.LAND, zorder=1, edgecolor='#C0C0C0', facecolor='#C0C0C0')
@@ -513,7 +529,6 @@ def scatter_plot(
            ax.add_feature(cartopy.feature.COASTLINE, zorder=10)
            gl = ax.gridlines(color='b', linestyle=(0, (1, 1)), xlocs=range(-180, 190, 10), ylocs=LATPOS, draw_labels=False, zorder=0)
        
-           # Colorbar: usa el mismo cmap y norm que los poligonos
            divider = make_axes_locatable(ax)
            ax3 = divider.append_axes("right", size="5%", pad=0.05, axes_class=plt.Axes)
        
@@ -530,12 +545,6 @@ def scatter_plot(
            def scientific(x, pos):
                return f'{x:.1e}'
        
-           # Etiquetas y leyendas
-          # if vartyp == 'obs':
-         #      vartyp = f'AVG(OBS) {units}'
-          #     units = f'AVG(obsvalue) {units}'
-          #     labels = [str(int(round(b))) for b in ticks]
-          #     cb2.ax.set_yticklabels(labels)
            if vartyp == 'dens' :
                if len(filesin) < 1:
                     cb2.ax.yaxis.set_major_formatter(FuncFormatter(scientific))
@@ -569,16 +578,6 @@ def scatter_plot(
            if len(filesin) == 1 and   vartyp == 'bcorr' :
                 cb2.ax.set_ylabel(f' BIAS Correction {units} ', fontsize=18, rotation=90, labelpad=20)
        
-
-
-          # else:
-          #     print ('sum(OBS)')
-          #     cb2.ax.set_ylabel(f'sum(nobs)/day', fontsize=18, rotation=90, labelpad=20)
-        
-           #if vartyp == 'dens':
-          #     cb2.ax.yaxis.set_major_formatter(FuncFormatter(scientific))
-       
-           # Títulos y anotaciones
            if len(filesin) < 1:
                fontsize = 12
                ax.text(0.00, 1.05, namesin[0], fontsize=fontsize, color='b', transform=ax.transAxes) 
@@ -607,7 +606,6 @@ def scatter_plot(
            ax.text(0.5, -0.08, 'Longitude', transform=ax.transAxes, ha='center', va='top', fontsize=14)
            ax.text(-0.06, 0.5, 'Latitude', transform=ax.transAxes, ha='center', va='bottom', rotation='vertical', fontsize=14)
        
-           # Box info inf. derecha
            props = dict(boxstyle='round', facecolor='wheat', alpha=0.5)
            if vartyp in [f'dens', 'nobs']:
                textstr = f'Nobs=%.2i (in %.2f days)' % (ONMAP, NDAYS)
@@ -624,8 +622,8 @@ def scatter_plot(
            plt.rcParams['axes.linewidth'] = 2
        
            if vcoord == 'join':
-               plt.savefig(f'{pathwork}/{family}/{fonction}_{proj}_{layers}_id_stn_{id_stn}_{region}_vcoord{vcoord}_varno{varno}.png', dpi=600, format='png')
+               plt.savefig(f'{pathwork}/{family}/{fonction}_{proj}_{layers}_id_stn_{id_stn}_{region}_vcoord_{int(vcoord)}_varno{varno}.png', dpi=600, format='png')
            else:
-               plt.savefig(f'{pathwork}/{family}/{fonction}_{proj}_{layers}_id_stn_{id_stn}_{region}_vcoord{int(vcoord)}_varno{varno}.png', dpi=600, format='png')
+               plt.savefig(f'{pathwork}/{family}/{fonction}_{proj}_{layers}_id_stn_{id_stn}_{region}_vcoord_{int(vcoord)}_varno{varno}.png', dpi=600, format='png')
            plt.close(fig) 
        
