@@ -104,7 +104,7 @@ def zone_ploat(
     import sqlalchemy
     import os
     from matplotlib.colors import ListedColormap, BoundaryNorm
-    
+    print ('s')
     method = 1
     vcoord_type = 'Channel'
     if family=='sw':
@@ -398,7 +398,7 @@ def zone_plot(
     import sqlalchemy
     import os
     from matplotlib.colors import ListedColormap, BoundaryNorm
-
+    print ("wwww")
     method = 1
     vcoord_type = 'Channel'
     if family == 'sw':
@@ -494,18 +494,29 @@ def zone_plot(
         ('omp', omp, 'O - P (Bias)', cmap_omp, norm_omp, bounds_omp)
     ]
 
+    # Canales únicos ordenados
+    unique_vcrd = np.sort(np.unique(vcrd))
+    
+    # Mapeo de canal real -> índice
+    vcrd_to_idx = {val: idx for idx, val in enumerate(unique_vcrd)}
+    
+    # Sustituimos vcrd por índice para plotear
+    vcrd_idx = np.array([vcrd_to_idx[val] for val in vcrd])
+    
+    # Altura de cada rectángulo (1 unidad de índice)
+    DeltP_idx = 1
+    
     for name, var, label, cmap, norm, bounds in variables:
-        fig, ax = plt.subplots(figsize=(14, 7))
+        fig, ax = plt.subplots(figsize=(14, 14))
         ax.set_xlim(lat_min, lat_max)
-        if vcoord_type.lower() == 'channel':
-            ax.set_ylim(vcoord_max_plot, vcoord_min_plot)
-        else:
-            ax.set_ylim(1000, 0) if family == 'sw' else ax.set_ylim(vcoord_min_plot, vcoord_max_plot)
-
+        
+        # Eje Y invertido para que canal menor esté arriba
+        ax.set_ylim(len(unique_vcrd) - 0.5, -0.5)
+    
         mappable = cm.ScalarMappable(norm=norm, cmap=cmap)
         colors_list = [mappable.to_rgba(x) for x in bounds]
         inds = np.digitize(var, bounds)
-
+    
         rects = []
         for i in range(len(var)):
             if not np.isnan(var[i]):
@@ -513,27 +524,76 @@ def zone_plot(
                 if val < bounds[0] or val > bounds[-1]:
                     FC = '#FF00FF'
                 else:
-                    idx = max(0, min(inds[i] - 1, len(colors_list) - 1))
-                    FC = colors_list[idx]
+                    idx_color = max(0, min(inds[i] - 1, len(colors_list) - 1))
+                    FC = colors_list[idx_color]
                 rect = Rectangle(
-                    (lat[i] - Delt_LAT / 2.0, vcrd[i] - DeltP / 2.0),
-                    Delt_LAT, DeltP,
+                    (lat[i] - Delt_LAT / 2.0, vcrd_idx[i] - DeltP_idx / 2.0),
+                    Delt_LAT, DeltP_idx,
                     facecolor=FC, edgecolor=FC
                 )
                 rects.append(rect)
-
+    
         ax.add_collection(PatchCollection(rects, match_original=True))
         ax.set_xlabel('Latitude')
-        ax.set_ylabel(vcoord_type)
-        ax.set_title(f'{label} vs Latitude and {vcoord_type} from {datestart} to {dateend},\nvarno={varno}, id_stn={id_stn}')
+        ax.set_ylabel('Channel')
+    
+        # Etiquetas con valores reales de canal
+        ax.set_yticks(range(len(unique_vcrd)))
+        ax.set_yticklabels(unique_vcrd, fontsize=5)
+    
+        ax.set_title(f'{label} vs Latitude and Channel from {datestart} to {dateend},\nvarno={varno}, id_stn={id_stn}')
         ax.grid(True, color='k')
-
+    
         cax = fig.add_axes([0.91, 0.15, 0.02, 0.7])
         cb = colorbar.ColorbarBase(cax, cmap=cmap, norm=norm, boundaries=bounds,
                                    orientation='vertical', ticks=bounds)
         cb.set_label(label)
-
-        output_file = os.path.join(pathwork, family, f'scatterplot_{"_".join(namesin)}_{name}_var{varno}_{id_stn}.png')
+        print ("wwwww")
+        output_file = os.path.join(pathwork, family, f'1scatterplot_{"_".join(namesin)}_{name}_var{varno}_{id_stn}.png')
         plt.savefig(output_file, format='png')
         plt.close(fig)
+    
 
+#    for name, var, label, cmap, norm, bounds in variables:
+#        fig, ax = plt.subplots(figsize=(14, 7))
+#        ax.set_xlim(lat_min, lat_max)
+#        if vcoord_type.lower() == 'channel':
+#            ax.set_ylim(vcoord_max_plot, vcoord_min_plot)
+#        else:
+#            ax.set_ylim(1000, 0) if family == 'sw' else ax.set_ylim(vcoord_min_plot, vcoord_max_plot)
+#
+#        mappable = cm.ScalarMappable(norm=norm, cmap=cmap)
+#        colors_list = [mappable.to_rgba(x) for x in bounds]
+#        inds = np.digitize(var, bounds)
+#
+#        rects = []
+#        for i in range(len(var)):
+#            if not np.isnan(var[i]):
+#                val = var[i]
+#                if val < bounds[0] or val > bounds[-1]:
+#                    FC = '#FF00FF'
+#                else:
+#                    idx = max(0, min(inds[i] - 1, len(colors_list) - 1))
+#                    FC = colors_list[idx]
+#                rect = Rectangle(
+#                    (lat[i] - Delt_LAT / 2.0, vcrd[i] - DeltP / 2.0),
+#                    Delt_LAT, DeltP,
+#                    facecolor=FC, edgecolor=FC
+#                )
+#                rects.append(rect)
+#
+#        ax.add_collection(PatchCollection(rects, match_original=True))
+#        ax.set_xlabel('Latitude')
+#        ax.set_ylabel(vcoord_type)
+#        ax.set_title(f'{label} vs Latitude and {vcoord_type} from {datestart} to {dateend},\nvarno={varno}, id_stn={id_stn}')
+#        ax.grid(True, color='k')
+#
+#        cax = fig.add_axes([0.91, 0.15, 0.02, 0.7])
+#        cb = colorbar.ColorbarBase(cax, cmap=cmap, norm=norm, boundaries=bounds,
+#                                   orientation='vertical', ticks=bounds)
+#        cb.set_label(label)
+#
+#        output_file = os.path.join(pathwork, family, f'scatterplot_{"_".join(namesin)}_{name}_var{varno}_{id_stn}.png')
+#        plt.savefig(output_file, format='png')
+#        plt.close(fig)
+#
